@@ -325,37 +325,74 @@ class Screen (pygame.sprite.LayeredUpdates):
         return self._canvas
 
 
-    def clear_canvas (self):
+    def clear_canvas (self, remove_sprites=False):
         '''
         Clear everything that was drawn on the screen.
         '''
 
         self._canvas.fill(0)
 
+        # Remove any sprites that are on the screen.
+        if remove_sprites:
+            width = self.width
+            height = self.height
+            for sprite in self:
+                if - width / 2 <= sprite.x <= width / 2 and - height / 2 <= sprite.y <= height / 2:
+                    self.remove(sprite)
+
 
     def clear_rect (self, corner1, corner2, remove_sprites=False):
         '''
         Clear a rectangular part of the screen.
         '''
 
+        # Ensure that the points are actually points
         try:
             corner1 = pygame.Vector2(corner1)
             corner2 = pygame.Vector2(corner2)
         except:
             raise ValueError("Invalid corner position!")
 
-        top_left = self.to_pygame_coordinates(min(corner1.x, corner2.x), max(corner1.y, corner2.y))
-        size = pygame.Vector2(abs(corner1.x - corner2.x), abs(corner1.y - corner2.y))
+        # Determine the coordinates of the sides
+        left = min(corner1.x, corner2.x)
+        right = max(corner1.x, corner2.x)
+        bottom = min(corner1.y, corner2.y)
+        top = max(corner1.y, corner2.y)
+
+        # Create a rect and fill that area with nothing
+        top_left = self.to_pygame_coordinates(left, top)
+        size = pygame.Vector2(right - left, top - bottom)
         rect = pygame.Rect(top_left, size)
         self._canvas.fill(0, rect)
 
+        # Remove any sprites that are in the rectangle.
+        if remove_sprites:
+            for sprite in self:
+                if left <= sprite.x <= right and bottom <= sprite.y <= top:
+                    self.remove(sprite)
+
 
     def clear_circle (self, center, radius, remove_sprites=False):
         '''
         Clear a circular part of the screen.
         '''
 
-        raise NotImplementedError()
+        # Ensure that the center and radius are good
+        try:
+            center = pygame.Vector2(center)
+            radius = float(radius)
+        except:
+            raise ValueError("Invalid argument!")
+
+        # Draw a circle of nothing
+        pygame_center = self.to_pygame_coordinates(center)
+        pygame.draw.circle(self._canvas, 0, pygame_center, radius)
+
+        # Remove any sprites that are in the circle
+        if remove_sprites:
+            for sprite in self:
+                if center.distance_to(sprite._pos) <= radius:
+                    self.remove(sprite)
 
 
     def clear (self):
@@ -459,11 +496,20 @@ class Screen (pygame.sprite.LayeredUpdates):
         '''
 
         if key is None:
-            self._key_press_funcs[None] = func
+            if func is None:
+                self._key_press_funcs.pop(None, None)
+            else:
+                self._key_press_funcs[None] = func
         elif isinstance(key, str):
-            self._key_press_funcs[pygame.key.key_code(key)] = func
+            if func is None:
+                self._key_press_funcs.pop(pygame.key.key_code(key), None)
+            else:
+                self._key_press_funcs[pygame.key.key_code(key)] = func
         elif isinstance(key, int):
-            self._key_press_funcs[key] = func
+            if func is None:
+                self._key_press_funcs.pop(key, None)
+            else:
+                self._key_press_funcs[key] = func
         else:
             try:
                 for k in key:
@@ -486,11 +532,20 @@ class Screen (pygame.sprite.LayeredUpdates):
         '''
 
         if key is None:
-            self._key_release_funcs[None] = func
+            if func is None:
+                self._key_release_funcs.pop(None, None)
+            else:
+                self._key_release_funcs[None] = func
         elif isinstance(key, str):
-            self._key_release_funcs[pygame.key.key_code(key)] = func
+            if func is None:
+                self._key_release_funcs.pop(pygame.key.key_code(key), None)
+            else:
+                self._key_release_funcs[pygame.key.key_code(key)] = func
         elif isinstance(key, int):
-            self._key_release_funcs[key] = func
+            if func is None:
+                self._key_release_funcs.pop(key, None)
+            else:
+                self._key_release_funcs[key] = func
         else:
             try:
                 for k in key:
@@ -516,11 +571,20 @@ class Screen (pygame.sprite.LayeredUpdates):
         '''
 
         if key is None:
-            self._key_hold_funcs[None] = func
+            if func is None:
+                self._key_hold_funcs.pop(None, None)
+            else:
+                self._key_hold_funcs[None] = func
         elif isinstance(key, str):
-            self._key_hold_funcs[pygame.key.key_code(key)] = func
+            if func is None:
+                self._key_hold_funcs.pop(pygame.key.key_code(key), None)
+            else:
+                self._key_hold_funcs[pygame.key.key_code(key)] = func
         elif isinstance(key, int):
-            self._key_hold_funcs[key] = func
+            if func is None:
+                self._key_hold_funcs.pop(key, None)
+            else:
+                self._key_hold_funcs[key] = func
         else:
             try:
                 for k in key:
